import 'package:flutter/material.dart';
import 'package:flutter_widget_from_html/flutter_widget_from_html.dart'; // Hiển thị HTML
import 'package:get/get.dart';
import 'onboarding_viewmodel.dart';

class OnboardingScreen extends StatelessWidget {
  final OnboardingViewModel controller = Get.find<OnboardingViewModel>();
  final FocusNode _focusNode = FocusNode();

  void hideKeyboard() {
    FocusScope.of(Get.context!).unfocus();
  }

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: hideKeyboard,
      child: Scaffold(
        resizeToAvoidBottomInset: false,
        body: Stack(
          children: [
            /// 📌 Hiển thị background từ API (hoặc ảnh mặc định)
            Obx(() => Positioned.fill(
              child: controller.backgroundUrl.value.isNotEmpty
                  ? Image.network(controller.backgroundUrl.value, fit: BoxFit.cover)
                  : Image.asset("assets/images/bg_onboarding.png", fit: BoxFit.cover),
            )),

            /// 📌 Nội dung chính
            AnimatedPadding(
              duration: const Duration(milliseconds: 300),
              padding: EdgeInsets.only(bottom: MediaQuery.of(context).viewInsets.bottom),
              child: Column(
                mainAxisAlignment: MainAxisAlignment.end,
                children: [
                  Container(
                    padding: const EdgeInsets.symmetric(horizontal: 20, vertical: 30),
                    decoration: const BoxDecoration(
                      color: Colors.redAccent,
                      borderRadius: BorderRadius.only(
                        topLeft: Radius.circular(30),
                        topRight: Radius.circular(30),
                      ),
                    ),
                    child: Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      mainAxisSize: MainAxisSize.min,
                      children: [
                        /// 📌 Tiêu đề (Hiển thị nội dung HTML từ API hoặc mặc định)
                        Obx(() => Visibility(
                          visible: !_focusNode.hasFocus,
                          child: HtmlWidget(
                            controller.contentHtml.value.isNotEmpty
                                ? controller.contentHtml.value
                                : """<h2 style="color: white;">Tiêu điểm dễ - Trừ tiền mê</h2>
                                       <p style="color: white;">Đừng bỏ lỡ cơ hội tích tới 30% tất cả giao dịch viễn thông 
                                       của các nhà mạng và đổi phiếu giảm giá tại hơn 200 thương hiệu được yêu thích nhất.</p>""",
                          ),
                        )),

                        /// 📌 Ô nhập số điện thoại
                        TextField(
                          focusNode: _focusNode,
                          keyboardType: TextInputType.phone,
                          style: const TextStyle(color: Colors.black),
                          decoration: InputDecoration(
                            filled: true,
                            fillColor: Colors.white,
                            hintText: "Nhập số điện thoại",
                            hintStyle: const TextStyle(color: Colors.grey),
                            border: OutlineInputBorder(
                              borderRadius: BorderRadius.circular(10),
                              borderSide: BorderSide.none,
                            ),
                            prefixIcon: const Icon(Icons.phone, color: Colors.black),
                          ),
                          onChanged: controller.updatePhoneNumber,
                        ),
                        const SizedBox(height: 20),

                        /// 📌 Nút Tiếp Tục
                        Obx(() => SizedBox(
                          width: double.infinity,
                          child: ElevatedButton(
                            onPressed: controller.isButtonEnabled
                                ? () {
                              debugPrint("Số điện thoại: ${controller.phoneNumber.value}");
                            }
                                : null,
                            style: ElevatedButton.styleFrom(
                              padding: const EdgeInsets.symmetric(vertical: 15),
                              backgroundColor: controller.isButtonEnabled ? Colors.white : Colors.white54,
                              shape: RoundedRectangleBorder(
                                borderRadius: BorderRadius.circular(10),
                              ),
                            ),
                            child: Text(
                              "Tiếp tục",
                              style: TextStyle(
                                color: controller.isButtonEnabled ? Colors.redAccent : Colors.grey,
                                fontSize: 18,
                                fontWeight: FontWeight.bold,
                              ),
                            ),
                          ),
                        )),
                        const SizedBox(height: 10),

                        /// 📌 Checkbox + Điều khoản sử dụng + Chính sách bảo mật
                        Row(
                          crossAxisAlignment: CrossAxisAlignment.center,
                          children: [
                            Obx(() => Checkbox(
                              value: controller.isChecked.value,
                              onChanged: controller.toggleCheckbox,
                              activeColor: Colors.white,
                              checkColor: Colors.red,
                              side: const BorderSide(color: Colors.white, width: 2),
                            )),
                            Expanded(
                              child: RichText(
                                text: TextSpan(
                                  style: const TextStyle(color: Colors.white70, fontSize: 12),
                                  children: [
                                    const TextSpan(text: "Bằng việc tiếp tục, bạn đã đọc và đồng ý với "),
                                    WidgetSpan(
                                      child: GestureDetector(
                                        onTap: () => debugPrint("Điều khoản sử dụng"),
                                        child: const Text(
                                          "Điều khoản sử dụng",
                                          style: TextStyle(
                                            decoration: TextDecoration.underline,
                                            color: Colors.white,
                                          ),
                                        ),
                                      ),
                                    ),
                                    const TextSpan(text: " và "),
                                    WidgetSpan(
                                      child: GestureDetector(
                                        onTap: () => debugPrint("Chính sách bảo mật"),
                                        child: const Text(
                                          "Chính sách bảo mật",
                                          style: TextStyle(
                                            decoration: TextDecoration.underline,
                                            color: Colors.white,
                                          ),
                                        ),
                                      ),
                                    ),
                                    const TextSpan(text: " của MyPoint"),
                                  ],
                                ),
                              ),
                            ),
                          ],
                        ),
                      ],
                    ),
                  ),
                ],
              ),
            ),
          ],
        ),
      ),
    );
  }
}
